<?php
/*
Plugin Name: mailto:staff
Plugin URI: http://decaf.de/mailto-staff/
Description: Generates mailto links on the dashboard referring to all user groups of the blog. Quite handy way of internal staff communication on multi-author blogs.
Version: 1.1
Author: DECAF
Author URI: http://decaf.de


	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
*/


	// actions
	add_action('activity_box_end', 'mailto');

	function mailto() {

		global $wpdb, $current_user;

		// get user data

		$admins       = array();
		$editors      = array();
		$authors      = array();
		$contributors = array();
		$subscribers  = array();

		$user_ids = $wpdb->get_col("SELECT ID FROM $wpdb->users");
		foreach($user_ids as $user_id) {

			if ($user_id == $current_user->ID) continue; // skip current user

			$user = get_userdata($user_id);
			$user_level = $user->user_level;
			$user_email = $user->user_email;

			// admins
			if ($user_level >= 8 && $user_level <= 10) {
				$admins[] = $user_email;
			}
			// editors
			if ($user_level >= 5 && $user_level <= 7 && $current_user->user_level >= 1) {
				$editors[] = $user_email;
			}
			// authors
			if ($user_level >= 2 && $user_level <= 4 && $current_user->user_level >= 2) {
				$authors[] = $user_email;
			}
			// contributors
			if ($user_level == 1 && $current_user->user_level >= 5) {
				$contributors[] = $user_email;
			}
			// subscribers
			if ($user_level == 0 && $current_user->user_level >= 5) {
				$subscribers[] = $user_email;
			}
		}

		// set default checkboxes

		$checked1 = ''; // admins
		$checked2 = ''; // editors
		$checked3 = ''; // authors
		$checked4 = ''; // contributors

		if ($current_user->user_level >= 8 && $current_user->user_level <= 10) {
			$checked1 = ' checked="checked"'; // admins
			$checked2 = ' checked="checked"'; // editors
			$checked3 = ' checked="checked"'; // authors
		}
		if ($current_user->user_level >= 5 && $current_user->user_level <= 7) {
			$checked2 = ' checked="checked"'; // editors
			$checked3 = ' checked="checked"'; // authors
		}
		if ($current_user->user_level >= 2 && $current_user->user_level <= 4) {
			$checked2 = ' checked="checked"'; // editors
			$checked3 = ' checked="checked"'; // authors
		}
		if ($current_user->user_level == 1) {
			$checked2 = ' checked="checked"'; // editors
		}
		if ($current_user->user_level == 0) {
			$checked1 = ' checked="checked"'; // admins
		}

		// build HTML

		$html       = '';
		$inner_html = '';
		$vars       = '';
		$numpeople  = count($admins)+count($editors)+count($authors)+count($contributors)+count($subscribers);

		if (count($admins) > 0) {
			$inner_html.= ' <label style="margin-right:5px;white-space:nowrap;"><input id="mailto1" onclick="toggle()" type="checkbox"'.$checked1.' name="chk1" value="admins" /> '.__('Administrator|User role').' ('.count($admins).')</label>';
			$vars.= 'admins = new Array("'.implode("\",\"", $admins).'"); ';
		}
		if (count($editors) > 0) {
			$inner_html.= ' <label style="margin-right:5px;white-space:nowrap;"><input id="mailto2" onclick="toggle()" type="checkbox"'.$checked2.' name="chk2" value="editors" /> '.__('Editor|User role').' ('.count($editors).')</label>';
			$vars.= 'editors = new Array("'.implode("\",\"", $editors).'"); ';
		}
		if (count($authors) > 0) {
			$inner_html.= ' <label style="margin-right:5px;white-space:nowrap;"><input id="mailto3" onclick="toggle()" type="checkbox"'.$checked3.' name="chk3" value="authors" /> '.__('Author|User role').' ('.count($authors).')</label>';
			$vars.= 'authors = new Array("'.implode("\",\"", $authors).'"); ';
		}
		if (count($contributors) > 0) {
			$inner_html.= ' <label style="margin-right:5px;white-space:nowrap;"><input id="mailto4" onclick="toggle()" type="checkbox"'.$checked4.' name="chk4" value="contributors" /> '.__('Contributor|User role').' ('.count($contributors).')</label>';
			$vars.= 'contributors = new Array("'.implode("\",\"", $contributors).'"); ';
		}
		if (count($subscribers) > 0) {
			$inner_html.= ' <label style="margin-right:5px;white-space:nowrap;"><input id="mailto5" onclick="toggle()" type="checkbox" name="chk5" value="subscribers" /> '.__('Subscriber|User role').' ('.count($subscribers).')</label>';
			$vars.= 'subscribers = new Array("'.implode("\",\"", $subscribers).'"); ';
		}

		if ($inner_html != '') {
			$html = '<p id="mailtostaff" style="border:1px solid #ddd;padding:8px;"><span style="margin-right:5px;"><a id="mailtolink" href="#"><img style="vertical-align:center;" src="../'.PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)).'/'.'group.png" alt="" /> <strong>'.__('E-mail').'</strong></a>: </span>'.$inner_html.'</p>';
		}

		if ($html != '') {
			$html.= '
				<script type="text/javascript">

					var admins = new Array(), editors = new Array(), authors = new Array(), contributors = new Array(), subscribers = new Array();
					'.$vars.'
					var currentuser = "'.$current_user->user_email.'";

					function removeselfanddoubles(a) {
						temp = new Array();
						for(i=0;i<a.length;i++) {
							if(!contains(temp, a[i]) && a[i]!=currentuser) {
								temp.length+=1;
								temp[temp.length-1]=a[i];
							}
						}
						return temp;
					}
					function contains(a, e) {
						for(j=0;j<a.length;j++) if(a[j]==e) return true;
						return false;
					}

					function toggle() {
						var mailtolink = "#";
						var recipients = new Array();
						if (admins.length > 0       && document.getElementById("mailto1").checked == true) { recipients = recipients.concat(admins); }
						if (editors.length > 0      && document.getElementById("mailto2").checked == true) { recipients = recipients.concat(editors); }
						if (authors.length > 0      && document.getElementById("mailto3").checked == true) { recipients = recipients.concat(authors); }
						if (contributors.length > 0 && document.getElementById("mailto4").checked == true) { recipients = recipients.concat(contributors); }
						if (subscribers.length > 0  && document.getElementById("mailto5").checked == true) { recipients = recipients.concat(subscribers); }
						recipients = removeselfanddoubles(recipients);

						if (recipients.length > 0) {
							if (document.getElementById("mailto5") && document.getElementById("mailto5").checked == true) {
								mailtolink = "mailto:" + currentuser + "?bcc=" + recipients.join(",");
							}
							else {
								mailtolink = "mailto:" + recipients.join(",");
							}
						}
						document.getElementById("mailtolink").href = mailtolink;
					}

					window.setTimeout("toggle()", 100);
				</script>
			';
		}

		// output
		echo $html;
	}
?>